DefaultRenderer

Struct DefaultRenderer 

pub struct DefaultRenderer {
    pub sounds: Vec<SoundHandle>,
    pub last_buffer_size: usize,
}
Default audio renderer.

Fields

sounds: Vec<SoundHandle>

All playing sounds.

last_buffer_size: usize

The last buffer size given by the cpal backend.

Implementations

Source

impl DefaultRenderer

pub fn add_sound(&mut self, sound: impl Into<SoundHandle>)

Start playing a sound. Accepts a type that can be converted into a SoundHandle.

pub fn has_sounds(&self) -> bool

Return whether the renderer has any playing sounds.