Struct kittyaudio::Frame

source ·
pub struct Frame {
    pub left: f32,
    pub right: f32,
}
Represents an audio sample. Stores a left and right channel.

Fields

left: f32

Left channel value. Float.

right: f32

Right channel value. Float.

Implementations

source

impl Frame

source

pub const ZERO: Self = _

A frame with all channels set to 0.0.

source

pub const fn new(left: f32, right: f32) -> Self

Create a new audio frame from left and right values.

source

pub const fn from_mono(value: f32) -> Self

Create a new audio frame from a single value.

Examples found in repository?
examples/custom_renderer.rs (line 15)
11
12
13
14
15
16
    fn next_frame(&mut self, sample_rate: u32) -> Frame {
        self.frame += 1;
        let time = self.frame as f64 / sample_rate as f64;
        let value = (time.sin() * 1200.0).sin() * 0.5;
        Frame::from_mono(value as f32)
    }