Struct kittyaudio::Resampler

source ·
pub struct Resampler { /* private fields */ }
Resamples audio from one sample rate to another.

Implementations

source

impl Resampler

source

pub const fn new(starting_index: usize) -> Self

Create a new Resampler.

source

pub fn push_frame(&mut self, frame: Frame, frame_index: usize)

Push a new frame to the resampler.

source

pub fn get(&self, fraction: f32) -> Frame

Get an interpolated frame from a resampler at a fractional value.

source

pub const fn current_frame_index(&self) -> usize

Return the index of the frame in the source sound that is currently playing in the audio stream.

This is not the same as the most recently pushed frame, as the stream mainly recieves an interpolated frame between self.frames[1] and self.frames[2]. self.frames[0] and self.frames[3] are used for the frame interpolation algorithm (see interpolate_frame).

source

pub fn outputting_silence(&self) -> bool

Return whether the resampler is outputting silence.